parserFwk.pyparsing.ParseExpression

Package parserFwk :: Module pyparsing :: Class ParseExpression |
[frames | no frames]

## Type ParseExpression

       object --+
                |
    ParserElement --+
                    |
                   ParseExpression

Known Subclasses:
  `And`, `Each`, `MatchFirst`, `Or`

Abstract subclass of ParserElement, for combining and post-processing parsed tokens.

Method Summary
| `__init__(self, exprs, savelist)`
| `__getitem__(self, i)`
| `__str__(self)`
| `append(self, other)`
| ``ignore`(self, other)` Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns.
| ``leaveWhitespace`(self)` Extends leaveWhitespace defined in base class, and also invokes leaveWhitespace on all contained expressions.
| ``setResultsName`(self, name, listAllMatches)` Define name for referencing matching tokens as a nested attribute of the returned parse results.
| `streamline(self)`
| ``validate`(self, validateTrace)` Check defined expressions for valid structure, check for infinite recursive definitions.
Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__getattr__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `normalizeParseActionArgs`, `parseFile`, `parseImpl`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setWhitespaceChars`, `skipIgnorables`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### ignore(self, other) Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. Overrides: `parserFwk.pyparsing.ParserElement.ignore` (inherited documentation)

### leaveWhitespace(self) Extends leaveWhitespace defined in base class, and also invokes leaveWhitespace on all contained expressions. Overrides: `parserFwk.pyparsing.ParserElement.leaveWhitespace`

### setResultsName(self, name, listAllMatches=False) Define name for referencing matching tokens as a nested attribute of the returned parse results. NOTE: this returns a *copy* of the original ParserElement object; this is so that the client can define a basic element, such as an integer, and reference it in multiple places with different names. Overrides: `parserFwk.pyparsing.ParserElement.setResultsName` (inherited documentation)

### validate(self, validateTrace=[]) Check defined expressions for valid structure, check for infinite recursive definitions. Overrides: `parserFwk.pyparsing.ParserElement.validate` (inherited documentation)

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net